==> kita-0.171.0.tar.gz: kita-0.171.0/kita/src/libkita/thread.h <==
/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef KITATHREAD_H
#define KITATHREAD_H

#include <qobject.h>
#include <qxml.h>
#include <qdict.h>

#include <stdio.h>

namespace KIO
{
    class Job;
}

class KURL;

namespace Kita
{
    /**
    @author Hideki Ikemoto
    */
    class Thread
    {
        Thread( const QString& datURL, const QString& threadName = QString::null );

    protected:
        Thread();

    public:
        ~Thread();

        const QString& datURL() const;
        const QString url() const;
        const QString& name() const;
        int resNum() const;
        const QString& boardName() const;

        static Thread* getByURL( const QString& datURL );
        static Thread* getByURLNew( const KURL& datURL );
        static void setName( const QString& datURL, QString threadName );
        static void replace( const QString& fromURL, const QString& toURL );
    private:
        QString m_datURL;
        QString m_threadName;
        static QDict<Thread>* m_threadDict;
    };

    class NullThread : public Thread
    {
    public:
        NullThread();
        ~NullThread();
    };
}

#endif

==> kita-0.173.0.tar.gz: kita-0.173.0/kita/src/libkita/thread.h <==
/***************************************************************************
*   Copyright (C) 2004 by Kita Developers                                 *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef KITATHREAD_H
#define KITATHREAD_H

#include <kurl.h>
#include <qdict.h>

namespace Kita
{
    /**
    @author Hideki Ikemoto
    */
    class Thread
    {
        static QDict<Thread>* m_threadDict;

        KURL m_datURL;
        QString m_threadName;
	int m_resNum;
	int m_readNum;
	int m_viewPos;
	bool m_isOpened;

    public:
        Thread( const KURL& datURL );
        ~Thread();

        const KURL& datURL() const;
	
        const QString& threadName() const;
	void setThreadName( QString threadName );

	const int resNum() const;
	void setResNum( int num );

	const int readNum() const;
	void setReadNum( int num );
	
	const int viewPos() const;
	void setViewPos( int viewPos );

	bool isOpened() const;
	void setIsOpened( bool isOpend );
	
	/*----------------------*/
	
        static Thread* getByURL( const KURL& datURL );
        static Thread* getByURLNew( const KURL& datURL );
        static void replace( const QString& fromURL, const QString& toURL );
    };
}

#endif
